@@ -6,7 +6,6 @@ import (
 	"os"
 	"regexp"
 	"strings"
-	"unicode"
 	"unicode/utf8"
 
 	log "github.com/sirupsen/logrus"
@@ -260,14 +259,14 @@ func consumeEncodedEvent(encodedEventSequences string) (*Event, string) {
 
 	mouseMatch := MOUSE_EVENT_REGEX.FindStringSubmatch(encodedEventSequences)
 	if mouseMatch != nil {
-		if mouseMatch[1] == "65" {
-			var event Event = EventMouse{buttons: MouseWheelDown}
-			return &event, strings.TrimPrefix(encodedEventSequences, mouseMatch[0])
-		}
 		if mouseMatch[1] == "64" {
 			var event Event = EventMouse{buttons: MouseWheelUp}
 			return &event, strings.TrimPrefix(encodedEventSequences, mouseMatch[0])
 		}
+		if mouseMatch[1] == "65" {
+			var event Event = EventMouse{buttons: MouseWheelDown}
+			return &event, strings.TrimPrefix(encodedEventSequences, mouseMatch[0])
+		}
 
 		log.Debug("Unhandled multi character mouse escape sequence(s): ", encodedEventSequences)
 		return nil, ""
@@ -275,26 +274,32 @@ func consumeEncodedEvent(encodedEventSequences string) (*Event, string) {
 
 	// No escape sequence prefix matched
 	runes := []rune(encodedEventSequences)
-	if len(runes) != 1 {
-		// This means one or more sequences should be added to
-		// escapeSequenceToKeyCode in keys.go.
-		log.Debug("Unhandled multi character terminal escape sequence(s): ", encodedEventSequences)
-
-		// Mark everything as consumed since we don't know how to proceed otherwise.
+	if len(runes) == 0 {
 		return nil, ""
 	}
 
-	var event Event
 	if runes[0] == '\x1b' {
-		event = EventKeyCode{KeyEscape}
-	} else if runes[0] == '\r' {
-		event = EventKeyCode{KeyEnter}
-	} else {
-		// Report the single rune
-		event = EventRune{rune: runes[0]}
+		if len(runes) != 1 {
+			// This means one or more sequences should be added to
+			// escapeSequenceToKeyCode in keys.go.
+			log.Debug("Unhandled multi character terminal escape sequence(s): ", encodedEventSequences)
+
+			// Mark everything as consumed since we don't know how to proceed otherwise.
+			return nil, ""
+		}
+
+		var event Event = EventKeyCode{KeyEscape}
+		return &event, string(runes[1:])
 	}
 
-	return &event, ""
+	if runes[0] == '\r' {
+		var event Event = EventKeyCode{KeyEnter}
+		return &event, string(runes[1:])
+	}
+
+	// Report the single rune
+	var event Event = EventRune{rune: runes[0]}
+	return &event, string(runes[1:])
 }
 
 // Returns screen width and height.
@@ -415,7 +420,7 @@ func renderLine(row []Cell) (string, int) {
 
 		style := cell.Style
 		runeToWrite := cell.Rune
-		if !unicode.IsPrint(runeToWrite) {
+		if !Printable(runeToWrite) {
 			// Highlight unprintable runes
 			style = Style{
 				fg:    NewColor16(7), // White
@@ -434,13 +439,14 @@ func renderLine(row []Cell) (string, int) {
 	}
 
 	// Set trailer attributes
-	builder.WriteString(lastCell.Style.RenderUpdateFrom(lastStyle))
+	trailerStyle := lastStyle.WithHyperlink(nil)
+	builder.WriteString(trailerStyle.RenderUpdateFrom(lastStyle))
 
 	// Clear to end of line
 	// https://en.wikipedia.org/wiki/ANSI_escape_code#CSI_(Control_Sequence_Introducer)_sequences
 	builder.WriteString("\x1b[K")
 
-	if lastStyle != StyleDefault {
+	if trailerStyle != StyleDefault {
 		// Reset style after each line
 		builder.WriteString("\x1b[m")
 	}
